starcluster.progressbar.ProgressBarWidgetHFill

Package starcluster :: Module progressbar :: Class ProgressBarWidgetHFill |
[hide private]
[frames] | no frames]

# Class ProgressBarWidgetHFill

source code

This is a variable width element of ProgressBar formatting.

The ProgressBar object will call it's update value, informing the width this object must the made. This is like TeX \hfill, it will expand to fill the line. You can use more than one in the same line, and they will all have the same width, and together will fill the line.

Instance Methods | [hide private]
update(self, pbar, width) Returns the string representing the widget. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, pbar, width) | source code
Returns the string representing the widget. The parameter pbar is a reference to the calling ProgressBar, where one can access attributes of the class for knowing how the update must be made. The parameter width is the total horizontal width the widget must have. At least this function must be overriden.